recalibration module
====================

This section contains the Python API reference for the
``uncertainty_toolbox.recalibration`` module, which contains code for recalibration
procedures, which aim to improve the calibration of a predictor.

uncertainty_toolbox.recalibration Module
########################################

.. automodule:: uncertainty_toolbox.recalibration
    :members:
